@@ -33,7 +33,7 @@ function (object, process = c("Longitudinal", "longitudinal", "Event", "event"),
         sk <- GQsurv$sk
         K <- length(sk)
         anyLeftTrunc <- object$y$anyLeftTrunc
-        if (anyLeftTrunc) {
+        if (length(anyLeftTrunc)) {
             ni <- tapply(object$y$id, object$y$id, length)
             TimeL <- rep(object$y$TimeL, ni)
             P <- (times - TimeL) / 2
@@ -88,7 +88,7 @@ function (object, process = c("Longitudinal", "longitudinal", "Event", "event"),
         W <- object$x$W[object$y$id, seq_along(gammas), drop = FALSE]
         eta.tw <- if (!is.null(W)) c(W %*% gammas) else rep(0, length(object$y$id))
         kn <- object$control$knots
-        W2s <- splineDesign(unlist(kn, use.names = FALSE), c(t(st)), 
+        W2s <- splines::splineDesign(unlist(kn, use.names = FALSE), c(t(st)), 
                             ord = object$control$ordSpline, outer.ok = TRUE)
         Vi <- exp(c(W2s %*% Bs.gammas) + tt)
         cumHaz <- exp(eta.tw) * P * tapply(rep(wk, length.out = length(Vi)) * Vi, id.GK, sum)
